@@ -5,6 +5,7 @@ import Skeleton from 'react-loading-skeleton';
 
 import { dateTime, GrafanaTheme2 } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
+import { config } from '@grafana/runtime';
 import {
   Alert,
   Avatar,
@@ -44,23 +45,12 @@ export type QueryDetails = {
 
 export interface QueryDetailsProps {
   query: SavedQuery;
-  editingQuery: boolean;
-  setEditingQuery: (editingQuery: boolean) => void;
-  onCloseDrawer?: () => void;
-  onEditQuerySuccess: (uid: string, isNew?: boolean) => void;
   usingHistory?: boolean;
 }
 
-function QueryLibraryDetailsComponent({
-  query,
-  editingQuery,
-  setEditingQuery,
-  onCloseDrawer,
-  onEditQuerySuccess,
-  usingHistory,
-}: QueryDetailsProps) {
+function QueryLibraryDetailsComponent({ query, usingHistory }: QueryDetailsProps) {
   const { register, setFocus, control } = useFormContext<QueryDetails>();
-  const { context, triggerAnalyticsEvent } = useQueryLibraryContext();
+  const { context, triggerAnalyticsEvent, isEditingQuery, setIsEditingQuery, closeDrawer } = useQueryLibraryContext();
 
   const { isFetching } = generatedAPI.endpoints.listQuery.useQueryState({});
   const { value: datasourceApi, loading: datasourceApiLoading } = useDatasource(query.datasourceRef);
@@ -83,10 +73,10 @@ function QueryLibraryDetailsComponent({
   const styles = useStyles2(getStyles);
 
   useEffect(() => {
-    if (editingQuery) {
+    if (isEditingQuery) {
       setFocus('title');
     }
-  }, [setFocus, editingQuery]);
+  }, [setFocus, isEditingQuery]);
 
   return (
     <Stack direction="column" justifyContent="space-between" flex={1} height="100%">
@@ -96,7 +86,7 @@ function QueryLibraryDetailsComponent({
           gap={1}
           alignItems="center"
           justifyContent="space-between"
-          marginBottom={editingQuery ? 0 : 2}
+          marginBottom={isEditingQuery ? 0 : 2}
         >
           {!usingHistory && (
             <Stack gap={1} alignItems="center" minWidth={0} flex={1}>
@@ -105,7 +95,7 @@ function QueryLibraryDetailsComponent({
                 src={datasourceApi?.meta.info.logos.small || icnDatasourceSvg}
                 alt={datasourceApi?.type}
               />
-              {editingQuery ? (
+              {isEditingQuery ? (
                 <Box flex={1} marginBottom={2}>
                   <Field label={t('query-library.query-details.title', 'Title')} noMargin>
                     <Input
@@ -126,25 +116,26 @@ function QueryLibraryDetailsComponent({
             </Stack>
           )}
           {isFetching && <Spinner />}
-          {!editingQuery && !usingHistory && (
+          {!isEditingQuery && !usingHistory && (
             <Button
               variant="primary"
               size="sm"
               onClick={() => {
                 triggerAnalyticsEvent(QueryLibraryInteractions.editQueryClicked);
-                setEditingQuery(true);
+                setIsEditingQuery(true);
               }}
               icon="pen"
               iconPlacement="right"
               disabled={isLocked || !canEditQuery(query)}
               aria-label={t('query-library.query-details.edit-button', 'Edit query')}
+              data-testid={selectors.components.queryLibraryDrawer.editButton}
             >
               <Trans i18nKey="query-library.query-details.edit-button-short">Edit</Trans>
             </Button>
           )}
         </Box>
         <Box marginBottom={2}>
-          {hasTemplateVariables && !editingQuery && (
+          {hasTemplateVariables && !isEditingQuery && (
             <Alert
               severity="warning"
               title={t('query-library.template-variables-warning.title', 'Query formatting unavailable')}
@@ -178,8 +169,9 @@ function QueryLibraryDetailsComponent({
               variant="success"
               fill="text"
               disabled={isLocked || !canEditQuery(query) || hasTemplateVariables}
+              data-testid={selectors.components.queryLibraryDrawer.editInExploreButton}
               onClick={() => {
-                onOpenInExplore(query, onCloseDrawer);
+                onOpenInExplore(query, closeDrawer);
                 triggerAnalyticsEvent(QueryLibraryInteractions.editInExploreClicked, {
                   datasourceType: query.datasourceType,
                 });
@@ -192,9 +184,16 @@ function QueryLibraryDetailsComponent({
         <Field label={t('query-library.query-details.datasource', 'Data source')}>
           <Input readOnly id={DATASOURCE_ID} value={query.datasourceName} />
         </Field>
-        <Field label={t('query-library.query-details.description', 'Description')}>
-          <Input id={DESCRIPTION_ID} readOnly={!editingQuery} {...register('description')} />
-        </Field>
+        {!usingHistory && (
+          <Field label={t('query-library.query-details.description', 'Description')}>
+            <Input
+              id={DESCRIPTION_ID}
+              readOnly={!isEditingQuery}
+              {...register('description')}
+              data-testid={selectors.components.queryLibraryDrawer.descriptionInput}
+            />
+          </Field>
+        )}
         {!usingHistory && (
           <Field label={t('query-library.query-details.tags', 'Tags')} htmlFor={TAGS_ID}>
             <Controller
@@ -206,7 +205,7 @@ function QueryLibraryDetailsComponent({
                   <TagsInput
                     {...field}
                     id={TAGS_ID}
-                    disabled={!editingQuery}
+                    disabled={!isEditingQuery}
                     onChange={(tags) => {
                       onChange(Array.from(new Set(tags)).sort());
                     }}
@@ -239,13 +238,14 @@ function QueryLibraryDetailsComponent({
         <Field label={t('query-library.query-details.date-added', 'Date added')}>
           <Input readOnly id={DATE_ADDED_ID} value={formattedTime} />
         </Field>
-        {!usingHistory && (
+        {!usingHistory && !config.featureToggles.savedQueriesRBAC && (
           <Field>
             <Checkbox
               label={t('query-library.query-details.make-query-visible', 'Share query with all users')}
               id={IS_VISIBLE_ID}
-              disabled={!editingQuery}
+              disabled={!isEditingQuery}
               {...register('isVisible')}
+              data-testid={selectors.components.queryLibraryDrawer.shareQueryWithAllUsersInput}
             />
           </Field>
         )}
