@@ -7,13 +7,13 @@ import { t } from '@grafana/i18n';
 import { getDataSourceSrv } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
 import { Button, Dropdown, FeatureBadge, Icon, Menu, useStyles2, useTheme2 } from '@grafana/ui';
-import { contextSrv } from 'app/core/services/context_srv';
 import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
 
 import { QueryLibraryInteractions } from './QueryLibraryAnalyticsEvents';
 import { QUERY_LIBRARY_LOCAL_STORAGE_KEYS } from './QueryLibraryDrawer';
 import { selectors } from './e2e-selectors/selectors';
 import { useQueryLibrarySave } from './hooks/useQueryLibrarySave';
+import { hasReadPermissions, hasWritePermissions } from './utils/identity';
 
 interface Props {
   query: DataQuery;
@@ -21,7 +21,7 @@ interface Props {
   onUpdateSuccess?: () => void;
   onSelectQuery?: (query: DataQuery) => void;
   datasourceFilters?: string[];
-  parentRef?: React.RefObject<HTMLElement>;
+  parentRef?: React.RefObject<HTMLElement | null>;
 }
 
 export function SavedQueryButtons({ query, app, onSelectQuery, datasourceFilters, parentRef }: Props) {
@@ -84,7 +84,7 @@ export function SavedQueryButtons({ query, app, onSelectQuery, datasourceFilters
   const MenuActions = () => {
     return (
       <Menu>
-        {contextSrv.isEditor ? (
+        {hasWritePermissions() ? (
           <Menu.Item
             label={t('query-operation.header.save-to-query-library', 'Save query')}
             onClick={onSaveNewQueryClick}
@@ -107,8 +107,8 @@ export function SavedQueryButtons({ query, app, onSelectQuery, datasourceFilters
     }
   }, [isOpen, triggerAnalyticsEvent, app]);
 
-  // Don't render buttons if they should be hidden
-  if (hideButtons) {
+  // Don't render buttons if user doesn't have read permission or datasource doesn't exist
+  if (!hasReadPermissions() || hideButtons) {
     return null;
   }
 
